butyrate is derived from two observational, population-based microbiome studies on the associations between butyrate-producing gut bacteria and the risk of hospitalisation due to infectious diseases. It provides a set of butyrate producers that were significantly increased or reduced in the patient group.

Value

A linkmap with 16 butyrate-producing microbial features characterised at the genus or species level.

References

Kullberg, Robert FJ, et al. "Association between butyrate-producing gut bacteria and the risk of infectious disease hospitalisation: results from two observational, population-based microbiome studies." The Lancet Microbe 5.9 (2024). https://doi.org/10.1016/S2666-5247(24)00079-X

Examples

# Import linkmap
data("butyrate", package = "ariadne")

# Print some pairs
head(butyrate)
#>                  taxname    cpd cpd.name
#> 1          Butyricimonas C00246 butyrate
#> 2            Odoribacter C00246 butyrate
#> 3           Agathobacter C00246 butyrate
#> 4        Anaerobutyricum C00246 butyrate
#> 5 Eubacterium ventriosum C00246 butyrate
#> 6           Anaerostipes C00246 butyrate