listResourceVersions shows the available versions for the different resources
registered in the ariadne database. Any of those versions can be passed to
ariadne. Resources labelled with "latest" cannot be
versioned as they are dynamically accessed via their API or SPARQL endpoint.
listResourceVersions(default = FALSE)A data.frame with information on registered resource versions.
# View all available resource versions
listResourceVersions()
#> resource version
#> 1 BugSigDB v1.3.1
#> 2 BugSigDB v1.3.0
#> 3 BugSigDB v1.2.2
#> 4 BugSigDB v1.2.1
#> 5 BugSigDB v1.2.0
#> 6 BugSigDB v1.1.0
#> 7 BugSigDB v1.0.2
#> 8 BugSigDB v1.0.1
#> 9 BugSigDB v1.0.0
#> 10 ChocoPhlAn v201901b
#> 16 GM v1
#> 11 GO 2026-03-25
#> 12 GO 2026-01-23
#> 13 GO 2025-10-10
#> 18 KEGG latest
#> 19 OTT latest
#> 20 Rhea latest
#> 17 TIGRFAMs v15
#> 21 UniProt latest
#> 14 WoL v2
#> 15 WoL v20April2021
#> url
#> 1 https://zenodo.org/records/19740674/
#> 2 https://zenodo.org/records/15272273/
#> 3 https://zenodo.org/records/13997429/
#> 4 https://zenodo.org/records/10627578/
#> 5 https://zenodo.org/records/10407666/
#> 6 https://zenodo.org/records/6468009/
#> 7 https://zenodo.org/records/5904281/
#> 8 https://zenodo.org/records/5819260/
#> 9 https://zenodo.org/records/5606166/
#> 10 https://zenodo.org/records/17100034/
#> 16 https://github.com/omixer/omixer-rpmR/raw/refs/heads/main/inst/extdata/
#> 11 https://release.geneontology.org/2026-03-25/
#> 12 https://release.geneontology.org/2026-01-23/
#> 13 https://release.geneontology.org/2025-10-10/
#> 18 https://www.genome.jp/kegg/
#> 19 https://opentreeoflife.github.io/
#> 20 https://www.rhea-db.org/
#> 17 https://ftp.ncbi.nlm.nih.gov/hmm/TIGRFAMs/release_15.0/
#> 21 https://www.uniprot.org/
#> 14 https://ftp.microbio.me/pub/wol2/
#> 15 https://ftp.microbio.me/pub/wol-20April2021/
# View default resource versions
listResourceVersions(default = TRUE)
#> resource version
#> 1 BugSigDB v1.3.1
#> 10 ChocoPhlAn v201901b
#> 16 GM v1
#> 11 GO 2026-03-25
#> 18 KEGG latest
#> 19 OTT latest
#> 20 Rhea latest
#> 17 TIGRFAMs v15
#> 21 UniProt latest
#> 14 WoL v2
#> url
#> 1 https://zenodo.org/records/19740674/
#> 10 https://zenodo.org/records/17100034/
#> 16 https://github.com/omixer/omixer-rpmR/raw/refs/heads/main/inst/extdata/
#> 11 https://release.geneontology.org/2026-03-25/
#> 18 https://www.genome.jp/kegg/
#> 19 https://opentreeoflife.github.io/
#> 20 https://www.rhea-db.org/
#> 17 https://ftp.ncbi.nlm.nih.gov/hmm/TIGRFAMs/release_15.0/
#> 21 https://www.uniprot.org/
#> 14 https://ftp.microbio.me/pub/wol2/